({"dateTimeAvailableFormats":["E, d/M","E d MMM","d MMMM","dd/MM","d/M","EEE, d/M/yyyy","MMM yy","MM/yyyy","MMMM yyyy","M/d","d","h:mm a","mm:ss","yyyy","M/yyyy","EEE, M/d/yyyy","MMM yyyy","EEE, MMM d, yyyy","MMMM yyyy","Q yyyy","QQQ yyyy"],"timeFormat-full":"HH:mm:ss v","timeFormat-medium":"HH:mm:ss","dateFormat-medium":"d MMM yyyy","dateFormat-full":"EEEE, d MMMM yyyy","timeFormat-long":"HH:mm:ss z","timeFormat-short":"HH:mm","dateFormat-short":"dd/MM/yyyy","dateFormat-long":"d MMMM yyyy","field-dayperiod":"AM/PM","field-minute":"Minute","eraNames":["Before Christ","Anno Domini"],"field-weekday":"Day of the Week","days-standAlone-wide":["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],"months-standAlone-narrow":["J","F","M","A","M","J","J","A","S","O","N","D"],"field-era":"Era","field-hour":"Hour","quarters-standAlone-abbr":["1st quarter","2nd quarter","3rd quarter","4th quarter"],"months-standAlone-abbr":["January","February","March","April","May","June","July","August","September","October","November","December"],"days-standAlone-narrow":["S","M","T","W","T","F","S"],"eraAbbr":["BC","AD"],"field-zone":"Zone","quarters-standAlone-wide":["1st quarter","2nd quarter","3rd quarter","4th quarter"],"dateTimeFormat":"{1} {0}","field-year":"Year","quarters-standAlone-narrow":["1","2","3","4"],"months-standAlone-wide":["January","February","March","April","May","June","July","August","September","October","November","December"],"field-week":"Week","months-format-abbr":["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],"field-month":"Month","quarters-format-abbr":["Q1","Q2","Q3","Q4"],"days-format-abbr":["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],"pm":"p.m.","days-format-narrow":["S","M","T","W","T","F","S"],"field-second":"Second","field-day":"Day","months-format-narrow":["J","F","M","A","M","J","J","A","S","O","N","D"],"am":"a.m.","days-standAlone-abbr":["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],"months-format-wide":["January","February","March","April","May","June","July","August","September","October","November","December"],"quarters-format-wide":["1st quarter","2nd quarter","3rd quarter","4th quarter"],"days-format-wide":["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],"eraNarrow":["B","A"],"dateTimeFormats-appendItem-Second":"{0} ({2}: {1})","days-standAlone-wide@localeAlias":{"bundle":"gregorian","target":"days-format-wide"},"dateTimeFormats-appendItem-Year":"{0} {1}","days-format-abbr@localeAlias":{"bundle":"gregorian","target":"days-format-wide"},"dateTimeFormats-appendItem-Week":"{0} ({2}: {1})","dateTimeFormats-appendItem-Timezone":"{0} {1}","months-standAlone-abbr@localeAlias":{"bundle":"gregorian","target":"months-format-wide"},"dateTimeFormats-appendItem-Month":"{0} ({2}: {1})","quarters-format-narrow@localeAlias":{"bundle":"gregorian","target":"quarters-standAlone-narrow"},"quarters-format-abbr@localeAlias":{"bundle":"gregorian","target":"quarters-format-wide"},"dateTimeFormats-appendItem-Minute":"{0} ({2}: {1})","months-format-abbr@localeAlias":{"bundle":"gregorian","target":"months-format-wide"},"months-standAlone-wide@localeAlias":{"bundle":"gregorian","target":"months-format-wide"},"eraNarrow@localeAlias":{"bundle":"gregorian","target":"eraAbbr"},"months-format-narrow@localeAlias":{"bundle":"gregorian","target":"months-standAlone-narrow"},"quarters-standAlone-abbr@localeAlias":{"bundle":"gregorian","target":"quarters-format-wide"},"dateTimeFormats-appendItem-Day":"{0} ({2}: {1})","quarters-format-narrow":["1","2","3","4"],"days-format-narrow@localeAlias":{"bundle":"gregorian","target":"days-standAlone-narrow"},"dateTimeFormats-appendItem-Quarter":"{0} ({2}: {1})","quarters-standAlone-wide@localeAlias":{"bundle":"gregorian","target":"quarters-format-wide"},"dateTimeFormats-appendItem-Day-Of-Week":"{0} {1}","dateTimeFormats-appendItem-Hour":"{0} ({2}: {1})","days-standAlone-abbr@localeAlias":{"bundle":"gregorian","target":"days-format-wide"},"eraNames@localeAlias":{"bundle":"gregorian","target":"eraAbbr"},"dateTimeFormats-appendItem-Era":"{0} {1}"})